[Libreoffice-commits] core.git: comphelper/source configmgr/source dbaccess/qa dbaccess/source filter/source forms/qa forms/source idlc/inc idlc/source offapi/com oox/source pyuno/source qadevOOo/runner registry/tools sfx2/qa sfx2/source stoc/source svtools/source sw/source ucbhelper/source ucb/source udkapi/com unodevtools/source writerfilter/source xmloff/source

Kenneth Beck overlordkb.dev at gmail.com
Wed Mar 6 01:40:12 PST 2013


 comphelper/source/property/opropertybag.cxx           |    2 -
 comphelper/source/property/propertybag.cxx            |    2 -
 configmgr/source/access.cxx                           |    2 -
 dbaccess/qa/complex/dbaccess/PropertyBag.java         |    4 +--
 dbaccess/source/core/dataaccess/datasource.cxx        |    8 +++---
 dbaccess/source/filter/xml/xmlExport.cxx              |    4 +--
 filter/source/config/cache/filtercache.cxx            |    2 -
 forms/qa/integration/forms/FormPropertyBags.java      |    4 +--
 forms/source/component/propertybaghelper.cxx          |   10 +++----
 idlc/inc/idlc/idlctypes.hxx                           |    2 -
 idlc/source/errorhandler.cxx                          |    4 +--
 offapi/com/sun/star/form/FormComponent.idl            |    2 -
 offapi/com/sun/star/sdb/DataSource.idl                |    4 +--
 oox/source/docprop/docprophandler.cxx                 |    2 -
 pyuno/source/module/unohelper.py                      |    6 ++--
 qadevOOo/runner/util/dbg.java                         |    4 +--
 registry/tools/regcompare.cxx                         |    2 -
 sfx2/qa/complex/sfx2/DocumentProperties.java          |   24 +++++++++---------
 sfx2/source/doc/SfxDocumentMetaData.cxx               |    2 -
 sfx2/source/doc/docinf.cxx                            |    2 -
 stoc/source/registry_tdprovider/tdservice.cxx         |    2 -
 stoc/source/tdmanager/tdmgr_check.cxx                 |    4 +--
 svtools/source/svhtml/parhtml.cxx                     |    2 -
 sw/source/filter/ww8/ww8par.cxx                       |    2 -
 sw/source/ui/vba/vbavariables.cxx                     |    2 -
 ucb/source/core/ucbstore.cxx                          |   10 +++----
 ucb/source/ucp/webdav/webdavcontent.cxx               |    6 ++--
 ucbhelper/source/provider/contenthelper.cxx           |   10 +++----
 udkapi/com/sun/star/beans/PropertyAttribute.idl       |    6 ++--
 unodevtools/source/skeletonmaker/javacompskeleton.cxx |    4 +--
 unodevtools/source/unodevtools/typeblob.cxx           |    2 -
 writerfilter/source/rtftok/rtfdocumentimpl.cxx        |    2 -
 xmloff/source/forms/elementimport.cxx                 |    2 -
 xmloff/source/forms/propertyexport.cxx                |    4 +--
 34 files changed, 75 insertions(+), 75 deletions(-)

New commits:
commit 21e1e859a7dc883a0347b6537e2518f4b2e9d0ff
Author: Kenneth Beck <overlordkb.dev at gmail.com>
Date:   Fri Mar 1 23:33:49 2013 -0600

    fdo#60724 change spelling error REMOVEABLE -> REMOVABLE
    
    Only applies to PropertyAttribute::REMOVEABLE, and all instances in comments.
    All other instances of the misspelling have remained the same.
    Example: AF_REMOVEABLE
    
    Change-Id: I391f4101bbc3e06689318235a37d616065bc1686
    Signed-off-by: Stephan Bergmann <sbergman at redhat.com>

diff --git a/comphelper/source/property/opropertybag.cxx b/comphelper/source/property/opropertybag.cxx
index ebb3dfa..f7418ba 100644
--- a/comphelper/source/property/opropertybag.cxx
+++ b/comphelper/source/property/opropertybag.cxx
@@ -499,7 +499,7 @@ namespace comphelper
                 if ( m_bAutoAddProperties )
                 {
                     // add the property
-                    sal_Int16 nAttributes = PropertyAttribute::BOUND | PropertyAttribute::REMOVEABLE | PropertyAttribute::MAYBEDEFAULT;
+                    sal_Int16 nAttributes = PropertyAttribute::BOUND | PropertyAttribute::REMOVABLE | PropertyAttribute::MAYBEDEFAULT;
                     addProperty( *pName, nAttributes, pProperty->Value );
                     continue;
                 }
diff --git a/comphelper/source/property/propertybag.cxx b/comphelper/source/property/propertybag.cxx
index 44285bf..bd519ed 100644
--- a/comphelper/source/property/propertybag.cxx
+++ b/comphelper/source/property/propertybag.cxx
@@ -151,7 +151,7 @@ namespace comphelper
     {
         const Property& rProp = getProperty( _rName );
             // will throw an UnknownPropertyException if necessary
-        if ( ( rProp.Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+        if ( ( rProp.Attributes & PropertyAttribute::REMOVABLE ) == 0 )
             throw NotRemoveableException( ::rtl::OUString(), NULL );
         const sal_Int32 nHandle = rProp.Handle;
 
diff --git a/configmgr/source/access.cxx b/configmgr/source/access.cxx
index c5f7d4b..3d554bf 100644
--- a/configmgr/source/access.cxx
+++ b/configmgr/source/access.cxx
@@ -2197,7 +2197,7 @@ css::beans::Property Access::asProperty() {
          css::beans::PropertyAttribute::CONSTRAINED |
          (nillable ? css::beans::PropertyAttribute::MAYBEVOID : 0) |
          (getRootAccess()->isUpdate()
-          ? (removable ? css::beans::PropertyAttribute::REMOVEABLE : 0)
+          ? (removable ? css::beans::PropertyAttribute::REMOVABLE : 0)
           : css::beans::PropertyAttribute::READONLY))); //TODO: MAYBEDEFAULT
 }
 
diff --git a/dbaccess/source/core/dataaccess/datasource.cxx b/dbaccess/source/core/dataaccess/datasource.cxx
index d858c4f..42cc640 100644
--- a/dbaccess/source/core/dataaccess/datasource.cxx
+++ b/dbaccess/source/core/dataaccess/datasource.cxx
@@ -478,7 +478,7 @@ namespace
             PropertyAttributeCache::const_iterator pos = m_rAttribs.find( _rProp.Name );
             OSL_ENSURE( pos != m_rAttribs.end(), "IsDefaultAndNotRemoveable: illegal property name!" );
             if ( pos != m_rAttribs.end() )
-                bRemoveable = ( ( pos->second & PropertyAttribute::REMOVEABLE ) != 0 );
+                bRemoveable = ( ( pos->second & PropertyAttribute::REMOVABLE ) != 0 );
 
             return !bRemoveable;
         }
@@ -871,8 +871,8 @@ namespace
 
         The method takes a property bag, and a sequence of property values to set for this bag.
         Upon return, every property which is not part of the given sequence is
-        <ul><li>removed from the bag, if it's a removeable property</li>
-            <li><em>or</em>reset to its default value, if it's not a removeable property</li>
+        <ul><li>removed from the bag, if it's a removable property</li>
+            <li><em>or</em>reset to its default value, if it's not a removable property</li>
         </ul>.
 
         @param  _rxPropertyBag
@@ -912,7 +912,7 @@ namespace
 
                 // this property is not to be set, but currently exists in the bag.
                 // -> Remove it, or reset it to the default.
-                if ( ( pExistentProperty->Attributes & PropertyAttribute::REMOVEABLE ) != 0 )
+                if ( ( pExistentProperty->Attributes & PropertyAttribute::REMOVABLE ) != 0 )
                     xPropertyContainer->removeProperty( pExistentProperty->Name );
                 else
                     xPropertyState->setPropertyToDefault( pExistentProperty->Name );
diff --git a/filter/source/config/cache/filtercache.cxx b/filter/source/config/cache/filtercache.cxx
index 255e02d..af342df 100644
--- a/filter/source/config/cache/filtercache.cxx
+++ b/filter/source/config/cache/filtercache.cxx
@@ -558,7 +558,7 @@ void FilterCache::addStatePropsToItem(      EItemType        eType,
         css::beans::Property aDescription = xItem->getAsProperty();
 
         sal_Bool bFinalized = ((aDescription.Attributes & css::beans::PropertyAttribute::READONLY  ) == css::beans::PropertyAttribute::READONLY  );
-        sal_Bool bMandatory = ((aDescription.Attributes & css::beans::PropertyAttribute::REMOVEABLE) != css::beans::PropertyAttribute::REMOVEABLE);
+        sal_Bool bMandatory = ((aDescription.Attributes & css::beans::PropertyAttribute::REMOVABLE) != css::beans::PropertyAttribute::REMOVABLE);
 
         rItem[PROPNAME_FINALIZED] <<= bFinalized;
         rItem[PROPNAME_MANDATORY] <<= bMandatory;
diff --git a/forms/qa/integration/forms/FormPropertyBags.java b/forms/qa/integration/forms/FormPropertyBags.java
index baa2b7b..47f5054 100644
--- a/forms/qa/integration/forms/FormPropertyBags.java
+++ b/forms/qa/integration/forms/FormPropertyBags.java
@@ -103,8 +103,8 @@ public class FormPropertyBags extends complexlib.ComplexTestCase implements XPro
         propContainer.addProperty( "SomeNumericValue", PropertyAttribute.BOUND, new Integer( 42 ) );
 
         XPropertySetInfo propertyInfo = textFieldModel.getPropertySetInfo();
-        assure( "Per service definition, dynamic properties are expected to be forced to be removeable",
-            ( propertyInfo.getPropertyByName("SomeBoundText").Attributes & PropertyAttribute.REMOVEABLE ) != 0 );
+        assure( "Per service definition, dynamic properties are expected to be forced to be removable",
+            ( propertyInfo.getPropertyByName("SomeBoundText").Attributes & PropertyAttribute.REMOVABLE ) != 0 );
 
         // a second addition of a property with an existent name should be rejected
         boolean caughtExpected = false;
diff --git a/idlc/inc/idlc/idlctypes.hxx b/idlc/inc/idlc/idlctypes.hxx
index 3c9568c..5f657f3 100644
--- a/idlc/inc/idlc/idlctypes.hxx
+++ b/idlc/inc/idlc/idlctypes.hxx
@@ -222,7 +222,7 @@ enum ParseState
     PS_TransientSeen,       // Seen TRANSIENT keyword
     PS_MayBeAmbigiousSeen,  // Seen MAYBEAMBIGIOUS keyword
     PS_MayBeDefaultSeen,    // Seen MAYBEDEFAULT keyword
-    PS_RemoveableSeen,      // Seen REMOVEABLE keyword
+    PS_RemoveableSeen,      // Seen REMOVABLE keyword
 
     PS_PropertySeen,        // Seen PROPERTY keyword
     PS_PropertyTypeSeen,    // Seen type decl for property
diff --git a/idlc/source/errorhandler.cxx b/idlc/source/errorhandler.cxx
index 464ff37..e919f5c 100644
--- a/idlc/source/errorhandler.cxx
+++ b/idlc/source/errorhandler.cxx
@@ -383,7 +383,7 @@ static const sal_Char* parseStateToMessage(ParseState state)
     case PS_MayBeDefaultSeen:
         return "Illegal syntax after MAYBEDEFAULT keyword";
     case PS_RemoveableSeen:
-        return "Illegal syntax after REMOVEABLE keyword";
+        return "Illegal syntax after REMOVABLE keyword";
     case PS_PropertySeen:
         return "Illegal syntax after PROPERTY keyword";
     case PS_PropertyTypeSeen:
@@ -457,7 +457,7 @@ static OString flagToString(sal_uInt32 flag)
     if ( (flag & AF_MAYBEDEFAULT) == AF_MAYBEDEFAULT )
         flagStr += "'maybedefault'";
     if ( (flag & AF_REMOVEABLE) == AF_REMOVEABLE )
-        flagStr += "'removeable'";
+        flagStr += "'removable'";
     if ( (flag & AF_ATTRIBUTE) == AF_ATTRIBUTE )
         flagStr += "'attribute'";
     if ( (flag & AF_PROPERTY) == AF_PROPERTY )
diff --git a/offapi/com/sun/star/form/FormComponent.idl b/offapi/com/sun/star/form/FormComponent.idl
index 66f8c37..3ab1545 100644
--- a/offapi/com/sun/star/form/FormComponent.idl
+++ b/offapi/com/sun/star/form/FormComponent.idl
@@ -78,7 +78,7 @@ published service FormComponent
         use by other instances.</p>
 
         <p>Note that dynamic properties added to a form component are, by definition,
-        removable. That is, the <member scope="com::sun::star::beans">PropertyAttribute::REMOVEABLE</member>
+        removable. That is, the <member scope="com::sun::star::beans">PropertyAttribute::REMOVABLE</member>
         will always be set, even if you do not specify it in the
         <member scope="com::sun::star::beans">XPropertyContainer::addProperty</member> call.</p>
 
diff --git a/offapi/com/sun/star/sdb/DataSource.idl b/offapi/com/sun/star/sdb/DataSource.idl
index 3a8f0eb..de6ab1e 100644
--- a/offapi/com/sun/star/sdb/DataSource.idl
+++ b/offapi/com/sun/star/sdb/DataSource.idl
@@ -162,13 +162,13 @@ published service DataSource
         a large set of such properties, no all of them are effectively used for a concrete data source, nonetheless,
         they're all present in the <code>Settings</code>.<br/>
         Such properties are not removable from the bag, that is, their
-        <member scope="com::sun::star::beans">PropertyAttribute::REMOVEABLE</member> attribute is <em>not</em> set.<br/>
+        <member scope="com::sun::star::beans">PropertyAttribute::REMOVABLE</member> attribute is <em>not</em> set.<br/>
         Usually, you'll find that all of this properties have the
         <member scope="com::sun::star::beans::">PropertyState::PropertyState_DEFAULT_VALUE</member> state.</p>
 
         <p><em>User-defined</em> properties are the ones which are added at runtime by any instance. They might or might
         not be removable, this depends on whether or not the code adding them specifies the
-        <member scope="com::sun::star::beans">PropertyAttribute::REMOVEABLE</member> attribute. Also, they might
+        <member scope="com::sun::star::beans">PropertyAttribute::REMOVABLE</member> attribute. Also, they might
         or might not have a default value, determined by the
         <member scope="com::sun::star::beans">PropertyAttribute::MAYBEDEFAULT</member> attribute at the time they're added
         to the bag.</p>
diff --git a/oox/source/docprop/docprophandler.cxx b/oox/source/docprop/docprophandler.cxx
index d0aa157..d81199f 100644
--- a/oox/source/docprop/docprophandler.cxx
+++ b/oox/source/docprop/docprophandler.cxx
@@ -74,7 +74,7 @@ void OOXMLDocPropHandler::AddCustomProperty( const uno::Any& aAny )
         try
         {
             xUserProps->addProperty( m_aCustomPropertyName,
-                    beans::PropertyAttribute::REMOVEABLE, aAny );
+                    beans::PropertyAttribute::REMOVABLE, aAny );
         }
         catch( beans::PropertyExistException& )
         {
diff --git a/pyuno/source/module/unohelper.py b/pyuno/source/module/unohelper.py
index 28c9ffd..2e200cc 100644
--- a/pyuno/source/module/unohelper.py
+++ b/pyuno/source/module/unohelper.py
@@ -39,7 +39,7 @@ from com.sun.star.beans.PropertyAttribute import \
      READONLY as PROP_ATTR_READONLY, \
      MAYBEAMBIGUOUS as PROP_ATTR_MAYBEAMBIGUOUS, \
      MAYBEDEFAULT as PROP_ATTR_MAYBEDEFAULT, \
-     REMOVEABLE as PROP_ATTR_REMOVEABLE
+     REMOVABLE as PROP_ATTR_REMOVABLE
 
 def _mode_to_str( mode ):
     ret = "[]"
@@ -53,8 +53,8 @@ def _mode_to_str( mode ):
 
 def _propertymode_to_str( mode ):
     ret = ""
-    if PROP_ATTR_REMOVEABLE & mode:
-        ret = ret + "removeable "
+    if PROP_ATTR_REMOVABLE & mode:
+        ret = ret + "removable "
     if PROP_ATTR_MAYBEDEFAULT & mode:
         ret = ret + "maybedefault "
     if PROP_ATTR_MAYBEAMBIGUOUS & mode:
diff --git a/qadevOOo/runner/util/dbg.java b/qadevOOo/runner/util/dbg.java
index 6b8f26a..9530746 100644
--- a/qadevOOo/runner/util/dbg.java
+++ b/qadevOOo/runner/util/dbg.java
@@ -192,8 +192,8 @@ public class dbg {
             if ((attr & PropertyAttribute.READONLY) != 0)
                     out.println("\t-READONLY");
 
-            if ((attr & PropertyAttribute.REMOVEABLE) != 0)
-                    out.println("\t-REMOVEABLE");
+            if ((attr & PropertyAttribute.REMOVABLE) != 0)
+                    out.println("\t-REMOVABLE");
 
             if ((attr & PropertyAttribute.TRANSIENT) != 0)
                     out.println("\t-TRANSIENT");
diff --git a/registry/tools/regcompare.cxx b/registry/tools/regcompare.cxx
index 798156f..49ba6cd 100644
--- a/registry/tools/regcompare.cxx
+++ b/registry/tools/regcompare.cxx
@@ -346,7 +346,7 @@ static OString getFieldAccess(RTFieldAccess fieldAccess)
     }
     if ( (fieldAccess & RT_ACCESS_REMOVEABLE) == RT_ACCESS_REMOVEABLE )
     {
-        ret += OString(ret.isEmpty() ? "REMOVEABLE" : ",REMOVEABLE");
+        ret += OString(ret.isEmpty() ? "REMOVABLE" : ",REMOVABLE");
     }
     if ( (fieldAccess & RT_ACCESS_ATTRIBUTE) == RT_ACCESS_ATTRIBUTE )
     {
diff --git a/sfx2/qa/complex/sfx2/DocumentProperties.java b/sfx2/qa/complex/sfx2/DocumentProperties.java
index 35f9b09..17faed7 100644
--- a/sfx2/qa/complex/sfx2/DocumentProperties.java
+++ b/sfx2/qa/complex/sfx2/DocumentProperties.java
@@ -351,16 +351,16 @@ public class DocumentProperties
             dur.Seconds = 555;
             dur.MilliSeconds = 444;
 
-            udpc.addProperty("Frobnicate", PropertyAttribute.REMOVEABLE, b);
-            udpc.addProperty("FrobDuration", PropertyAttribute.REMOVEABLE, dur);
-            udpc.addProperty("FrobDuration2", PropertyAttribute.REMOVEABLE, t);
-            udpc.addProperty("FrobEndDate", PropertyAttribute.REMOVEABLE, date);
-            udpc.addProperty("FrobStartTime", PropertyAttribute.REMOVEABLE, dt);
-            udpc.addProperty("Pi", PropertyAttribute.REMOVEABLE, new Double(d));
-            udpc.addProperty("Foo", PropertyAttribute.REMOVEABLE, "bar");
-            udpc.addProperty("Removed", PropertyAttribute.REMOVEABLE, "bar");
+            udpc.addProperty("Frobnicate", PropertyAttribute.REMOVABLE, b);
+            udpc.addProperty("FrobDuration", PropertyAttribute.REMOVABLE, dur);
+            udpc.addProperty("FrobDuration2", PropertyAttribute.REMOVABLE, t);
+            udpc.addProperty("FrobEndDate", PropertyAttribute.REMOVABLE, date);
+            udpc.addProperty("FrobStartTime", PropertyAttribute.REMOVABLE, dt);
+            udpc.addProperty("Pi", PropertyAttribute.REMOVABLE, new Double(d));
+            udpc.addProperty("Foo", PropertyAttribute.REMOVABLE, "bar");
+            udpc.addProperty("Removed", PropertyAttribute.REMOVABLE, "bar");
             // #i94175#: empty property name is valid ODF 1.1
-            udpc.addProperty("", PropertyAttribute.REMOVEABLE, "eeeeek");
+            udpc.addProperty("", PropertyAttribute.REMOVABLE, "eeeeek");
             try {
                 udpc.removeProperty("Info 1");
                 udpc.removeProperty("Removed");
@@ -369,7 +369,7 @@ public class DocumentProperties
             }
 
             try {
-                udpc.addProperty("Forbidden", PropertyAttribute.REMOVEABLE,
+                udpc.addProperty("Forbidden", PropertyAttribute.REMOVABLE,
                     new String[] { "foo", "bar" });
                 fail("inserting value of non-supported type did not fail");
             } catch (IllegalTypeException e) {
@@ -454,14 +454,14 @@ public class DocumentProperties
             xMB.addModifyListener(listener);
             xDP.setAuthor("not me");
             assertTrue("Listener Author", listener.reset());
-            udpc.addProperty("Listener", PropertyAttribute.REMOVEABLE, "foo");
+            udpc.addProperty("Listener", PropertyAttribute.REMOVABLE, "foo");
             assertTrue("Listener UserDefined Add", listener.reset());
             udps.setPropertyValue("Listener", "bar");
             assertTrue("Listener UserDefined Set", listener.reset());
             udpc.removeProperty("Listener");
             assertTrue("Listener UserDefined Remove", listener.reset());
             xMB.removeModifyListener(listener);
-            udpc.addProperty("Listener2", PropertyAttribute.REMOVEABLE, "foo");
+            udpc.addProperty("Listener2", PropertyAttribute.REMOVABLE, "foo");
             assertTrue("Removed Listener UserDefined Add", !listener.reset());
 
             System.out.println("...done");
diff --git a/sfx2/source/doc/SfxDocumentMetaData.cxx b/sfx2/source/doc/SfxDocumentMetaData.cxx
index cfecf3f..8e0d05b 100644
--- a/sfx2/source/doc/SfxDocumentMetaData.cxx
+++ b/sfx2/source/doc/SfxDocumentMetaData.cxx
@@ -1337,7 +1337,7 @@ void SAL_CALL SfxDocumentMetaData::init(
         }
         try {
             m_xUserDefined->addProperty(name,
-                css::beans::PropertyAttribute::REMOVEABLE, any);
+                css::beans::PropertyAttribute::REMOVABLE, any);
         } catch (const css::beans::PropertyExistException &) {
             DBG_WARNING1("SfxDocumentMetaData: duplicate: %s",
                     OUStringToOString(name, RTL_TEXTENCODING_UTF8).getStr());
diff --git a/sfx2/source/doc/docinf.cxx b/sfx2/source/doc/docinf.cxx
index e58afd7..d1b1561 100644
--- a/sfx2/source/doc/docinf.cxx
+++ b/sfx2/source/doc/docinf.cxx
@@ -156,7 +156,7 @@ sal_uInt32 SFX2_DLLPUBLIC LoadOlePropertySet(
                 try
                 {
                     xUserDefined->addProperty( aPropName,
-                        beans::PropertyAttribute::REMOVEABLE, aPropValue );
+                        beans::PropertyAttribute::REMOVABLE, aPropValue );
                 }
                 catch (const uno::Exception&)
                 {
diff --git a/stoc/source/registry_tdprovider/tdservice.cxx b/stoc/source/registry_tdprovider/tdservice.cxx
index 185ae87..585a026 100644
--- a/stoc/source/registry_tdprovider/tdservice.cxx
+++ b/stoc/source/registry_tdprovider/tdservice.cxx
@@ -282,7 +282,7 @@ ServiceTypeDescriptionImpl::getProperties()
         if ( nFlags & RT_ACCESS_MAYBEDEFAULT )
             nAttribs |= beans::PropertyAttribute::MAYBEDEFAULT;
         if ( nFlags & RT_ACCESS_REMOVEABLE )
-            nAttribs |= beans::PropertyAttribute::REMOVEABLE;
+            nAttribs |= beans::PropertyAttribute::REMOVABLE;
 
         OSL_ENSURE( !(nFlags & RT_ACCESS_PROPERTY),
                     "### RT_ACCESS_PROPERTY is unexpected here!" );
diff --git a/stoc/source/tdmanager/tdmgr_check.cxx b/stoc/source/tdmanager/tdmgr_check.cxx
index c9679dd..ff9e763 100644
--- a/stoc/source/tdmanager/tdmgr_check.cxx
+++ b/stoc/source/tdmanager/tdmgr_check.cxx
@@ -88,8 +88,8 @@ OUString getPropertyFlagsAsString( sal_Int16 attributes )
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("MAYBEAMBIGUOUS, ") );
     if ((attributes & beans::PropertyAttribute::MAYBEDEFAULT) != 0)
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("MAYBEDEFAULT, ") );
-    if ((attributes & beans::PropertyAttribute::REMOVEABLE) != 0)
-        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("REMOVEABLE, ") );
+    if ((attributes & beans::PropertyAttribute::REMOVABLE) != 0)
+        buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("REMOVABLE, ") );
     if ((attributes & beans::PropertyAttribute::OPTIONAL) != 0)
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("OPTIONAL") );
     else if (buf.getLength() > 0)
diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index 14444e4..e34f16c 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -2203,7 +2203,7 @@ bool HTMLParser::ParseMetaOptionsImpl(
                         = i_xDocProps->getUserDefinedProperties();
                     try {
                         xUDProps->addProperty(aName,
-                            beans::PropertyAttribute::REMOVEABLE,
+                            beans::PropertyAttribute::REMOVABLE,
                             uno::makeAny(::rtl::OUString(aContent)));
                         AddMetaUserDefined(aName);
                         bChanged = true;
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 8145ef9..463698e 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -4133,7 +4133,7 @@ void SwWW8ImplReader::ReadDocVars()
             aValue <<= ::rtl::OUString(aDocValueStrings[i]);
             try {
                 xUserDefinedProps->addProperty( name,
-                    beans::PropertyAttribute::REMOVEABLE,
+                    beans::PropertyAttribute::REMOVABLE,
                     aValue );
             } catch (const uno::Exception &) {
                 // ignore
diff --git a/sw/source/ui/vba/vbavariables.cxx b/sw/source/ui/vba/vbavariables.cxx
index 33e61c3..3ab7e95 100644
--- a/sw/source/ui/vba/vbavariables.cxx
+++ b/sw/source/ui/vba/vbavariables.cxx
@@ -69,7 +69,7 @@ SwVbaVariables::Add( const rtl::OUString& rName, const uno::Any& rValue ) throw
     else
         aValue <<= rtl::OUString();
     uno::Reference< beans::XPropertyContainer > xPropertyContainer( mxUserDefined, uno::UNO_QUERY_THROW );
-    xPropertyContainer->addProperty( rName, beans::PropertyAttribute::MAYBEVOID | beans::PropertyAttribute::REMOVEABLE, aValue );
+    xPropertyContainer->addProperty( rName, beans::PropertyAttribute::MAYBEVOID | beans::PropertyAttribute::REMOVABLE, aValue );
 
     return uno::makeAny( uno::Reference< word::XVariable >( new SwVbaVariable( getParent(), mxContext, mxUserDefined, rName ) ) );
 }
diff --git a/udkapi/com/sun/star/beans/PropertyAttribute.idl b/udkapi/com/sun/star/beans/PropertyAttribute.idl
index 6c2a455..36fc4f8 100644
--- a/udkapi/com/sun/star/beans/PropertyAttribute.idl
+++ b/udkapi/com/sun/star/beans/PropertyAttribute.idl
@@ -74,12 +74,12 @@ published constants PropertyAttribute
     /** indicates that the property can be removed
         (i.e., by calling <member>XPropertyContainer::removeProperty</member>).
      */
-    const short REMOVEABLE = 128;
+    const short REMOVABLE = 128;
 
     /** @deprecated
-        same as <const>PropertyAttribute::REMOVEABLE</const>.
+        same as <const>PropertyAttribute::REMOVABLE</const>.
      */
-    const short REMOVABLE = 128;
+    const short REMOVEABLE = 128;
 
     /** indicates that a property is optional.
 
diff --git a/unodevtools/source/skeletonmaker/javacompskeleton.cxx b/unodevtools/source/skeletonmaker/javacompskeleton.cxx
index 772a55a..4ddaf59 100644
--- a/unodevtools/source/skeletonmaker/javacompskeleton.cxx
+++ b/unodevtools/source/skeletonmaker/javacompskeleton.cxx
@@ -194,7 +194,7 @@ bool checkAttribute(OStringBuffer& attributeValue, sal_uInt16 attribute)
         /* com::sun::star::beans::PropertyValue::READONLY */ 16,
         /* com::sun::star::beans::PropertyValue::MAYBEAMBIGIOUS */ 32,
         /* com::sun::star::beans::PropertyValue::MAYBEDEFAULT */ 64,
-        /* com::sun::star::beans::PropertyValue::REMOVEABLE */ 128,
+        /* com::sun::star::beans::PropertyValue::REMOVABLE */ 128,
         /* com::sun::star::beans::PropertyValue::OPTIONAL */ 256 };
 
     for (sal_uInt16 i = 0; i < 9; i++)
@@ -228,7 +228,7 @@ bool checkAttribute(OStringBuffer& attributeValue, sal_uInt16 attribute)
                 attributeValue.append("PropertyAttribute.MAYBEDEFAULT");
                 break;
             case 128:
-                attributeValue.append("PropertyAttribute.REMOVEABLE");
+                attributeValue.append("PropertyAttribute.REMOVABLE");
                 break;
             case 256:
                 attributeValue.append("PropertyAttribute.OPTIONAL");
diff --git a/unodevtools/source/unodevtools/typeblob.cxx b/unodevtools/source/unodevtools/typeblob.cxx
index b2d1ab6..b174ba0 100644
--- a/unodevtools/source/unodevtools/typeblob.cxx
+++ b/unodevtools/source/unodevtools/typeblob.cxx
@@ -264,7 +264,7 @@ RTFieldAccess checkPropertyFlags(short flags) {
         propertyFlags |= RT_ACCESS_MAYBEAMBIGUOUS;
     case PropertyAttribute::MAYBEDEFAULT:
         propertyFlags |= RT_ACCESS_MAYBEDEFAULT;
-    case PropertyAttribute::REMOVEABLE:
+    case PropertyAttribute::REMOVABLE:
         propertyFlags |= RT_ACCESS_REMOVEABLE;
     case PropertyAttribute::OPTIONAL:
         propertyFlags |= RT_ACCESS_OPTIONAL;
diff --git a/writerfilter/source/rtftok/rtfdocumentimpl.cxx b/writerfilter/source/rtftok/rtfdocumentimpl.cxx
index 9488801..0e05b75 100644
--- a/writerfilter/source/rtftok/rtfdocumentimpl.cxx
+++ b/writerfilter/source/rtftok/rtfdocumentimpl.cxx
@@ -3846,7 +3846,7 @@ int RTFDocumentImpl::popState()
         if (m_xDocumentProperties.is())
         {
             uno::Reference<beans::XPropertyContainer> xUserDefinedProperties = m_xDocumentProperties->getUserDefinedProperties();
-            xUserDefinedProperties->addProperty(aName, beans::PropertyAttribute::REMOVEABLE,
+            xUserDefinedProperties->addProperty(aName, beans::PropertyAttribute::REMOVABLE,
                     uno::makeAny(m_aStates.top().aDestinationText.makeStringAndClear()));
         }
     }
diff --git a/xmloff/source/forms/elementimport.cxx b/xmloff/source/forms/elementimport.cxx
index 2f037ad..7c01677 100644
--- a/xmloff/source/forms/elementimport.cxx
+++ b/xmloff/source/forms/elementimport.cxx
@@ -372,7 +372,7 @@ namespace xmloff
 
                     xDynamicProperties->addProperty(
                         aPropValues->Name,
-                        PropertyAttribute::BOUND | PropertyAttribute::REMOVEABLE,
+                        PropertyAttribute::BOUND | PropertyAttribute::REMOVABLE,
                         aPropValues->Value
                     );
 
diff --git a/xmloff/source/forms/propertyexport.cxx b/xmloff/source/forms/propertyexport.cxx
index 070a192..c86c6ac 100644
--- a/xmloff/source/forms/propertyexport.cxx
+++ b/xmloff/source/forms/propertyexport.cxx
@@ -85,7 +85,7 @@ namespace xmloff
         bool bIsDefaultValue =    m_xPropertyState.is()
                             &&  ( PropertyState_DEFAULT_VALUE == m_xPropertyState->getPropertyState( i_propertyName ) );
         bool bIsDynamicProperty =  m_xPropertyInfo.is()
-                                && ( ( m_xPropertyInfo->getPropertyByName( i_propertyName ).Attributes & PropertyAttribute::REMOVEABLE ) != 0 );
+                                && ( ( m_xPropertyInfo->getPropertyByName( i_propertyName ).Attributes & PropertyAttribute::REMOVABLE ) != 0 );
         return ( !bIsDefaultValue || bIsDynamicProperty );
     }
 
@@ -249,7 +249,7 @@ namespace xmloff
             // no read-only props
             if ( ( pProperties->Attributes & PropertyAttribute::READONLY ) != 0 )
                 // except they're dynamically added
-                if ( ( pProperties->Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+                if ( ( pProperties->Attributes & PropertyAttribute::REMOVABLE ) == 0 )
                     continue;
             m_aRemainingProps.insert(pProperties->Name);
         }


More information about the Libreoffice-commits mailing list
diff --git a/dbaccess/qa/complex/dbaccess/PropertyBag.java b/dbaccess/qa/complex/dbaccess/PropertyBag.java
index 0788454..02389a7 100644
--- a/dbaccess/qa/complex/dbaccess/PropertyBag.java
+++ b/dbaccess/qa/complex/dbaccess/PropertyBag.java
@@ -91,7 +91,7 @@ public class PropertyBag extends TestCase
         }
 
         // try removing the property we just added - this should fail, as it does not have
         // the REMOVEABLE attribute
         caughtExpected = false;
         try
         {
@@ -101,7 +101,7 @@ public class PropertyBag extends TestCase
         catch(com.sun.star.uno.Exception e) { }
         if ( !caughtExpected )
         {
-            fail("removing non-removeable properties is expected to fail - but it didn't");
+            fail("removing non-removable properties is expected to fail - but it didn't");
         }
 
         // try removing a non-existent property
@@ -91,7 +91,7 @@ public class PropertyBag extends TestCase
 
         // try removing the property we just added - this should fail, as it does not have
-        // the REMOVEABLE attribute
+        // the REMOVABLE attribute
         caughtExpected = false;
         try
diff --git a/dbaccess/source/filter/xml/xmlExport.cxx b/dbaccess/source/filter/xml/xmlExport.cxx
index 53fbca5..7afd9be 100644
--- a/dbaccess/source/filter/xml/xmlExport.cxx
+++ b/dbaccess/source/filter/xml/xmlExport.cxx
@@ -389,9 +389,9 @@ void ODBExport::exportDataSource()
 
             if ( eToken == XML_TOKEN_INVALID )
             {
                 // for properties which are not REMOVEABLE, we care for their state, and
                 // only export them if they're not DEFAULTed
-                if ( ( pProperties->Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+                if ( ( pProperties->Attributes & PropertyAttribute::REMOVABLE ) == 0 )
                 {
                     PropertyState ePropertyState = xSettingsState->getPropertyState( pProperties->Name );
                     if ( PropertyState_DEFAULT_VALUE == ePropertyState )
@@ -389,9 +389,9 @@ void ODBExport::exportDataSource()
             if ( eToken == XML_TOKEN_INVALID )
             {
-                // for properties which are not REMOVEABLE, we care for their state, and
+                // for properties which are not REMOVABLE, we care for their state, and
                 // only export them if they're not DEFAULTed
diff --git a/forms/source/component/propertybaghelper.cxx b/forms/source/component/propertybaghelper.cxx
index a9ababe..e36e8fd 100644
--- a/forms/source/component/propertybaghelper.cxx
+++ b/forms/source/component/propertybaghelper.cxx
@@ -194,9 +194,9 @@ namespace frm
             throw PropertyExistException( _rName, m_rContext.getPropertiesInterface() );
 
         //----------------------------------------------
-        // normalize the REMOVEABLE attribute - the FormComponent service
-        // requires that all dynamic properties are REMOVEABLE
-        _nAttributes |= PropertyAttribute::REMOVEABLE;
+        // normalize the REMOVABLE attribute - the FormComponent service
+        // requires that all dynamic properties are REMOVABLE
+        _nAttributes |= PropertyAttribute::REMOVABLE;
 
         //----------------------------------------------
         // find a free handle
@@ -214,11 +214,11 @@ namespace frm
         ::osl::MutexGuard aGuard( m_rContext.getMutex() );
         impl_nts_checkDisposed_throw();
 
         // check whether it's removeable at all
         Reference< XMultiPropertySet > xMe( m_rContext.getPropertiesInterface(), UNO_QUERY_THROW );
         Reference< XPropertySetInfo > xPSI( xMe->getPropertySetInfo(), UNO_QUERY_THROW );
         Property aProperty( xPSI->getPropertyByName( _rName ) );
-        if ( ( aProperty.Attributes & PropertyAttribute::REMOVEABLE ) == 0 )
+        if ( ( aProperty.Attributes & PropertyAttribute::REMOVABLE ) == 0 )
             throw NotRemoveableException( _rName, xMe );
 
         m_aDynamicProperties.removeProperty( _rName );
@@ -214,11 +214,11 @@ namespace frm
         impl_nts_checkDisposed_throw();
 
-        // check whether it's removeable at all
+        // check whether it's removable at all
         Reference< XMultiPropertySet > xMe( m_rContext.getPropertiesInterface(), UNO_QUERY_THROW );
         Reference< XPropertySetInfo > xPSI( xMe->getPropertySetInfo(), UNO_QUERY_THROW );
diff --git a/ucb/source/core/ucbstore.cxx b/ucb/source/core/ucbstore.cxx
index 6fdffba..f717faf 100644
--- a/ucb/source/core/ucbstore.cxx
+++ b/ucb/source/core/ucbstore.cxx
@@ -1704,8 +1704,8 @@ void SAL_CALL PersistentPropertySet::addProperty(
         }
     }
 
-    // Property is always removeable.
-    Attributes |= PropertyAttribute::REMOVEABLE;
+    // Property is always removable.
+    Attributes |= PropertyAttribute::REMOVABLE;
 
     // Add property.
 
@@ -1852,7 +1852,7 @@ void SAL_CALL PersistentPropertySet::removeProperty( const OUString& Name )
         if ( !xRootHierNameAccess->hasByHierarchicalName( aFullPropName ) )
             throw UnknownPropertyException();
 
-        // Property removeable?
+        // Property removable?
         try
         {
             OUString aFullAttrName = aFullPropName;
@@ -1862,9 +1862,9 @@ void SAL_CALL PersistentPropertySet::removeProperty( const OUString& Name )
             if ( xRootHierNameAccess->getByHierarchicalName( aFullAttrName )
                     >>= nAttribs )
             {
-                if ( !( nAttribs & PropertyAttribute::REMOVEABLE ) )
+                if ( !( nAttribs & PropertyAttribute::REMOVABLE ) )
                 {
-                    // Not removeable!
+                    // Not removable!
                     throw NotRemoveableException();
                 }
             }
diff --git a/ucb/source/ucp/webdav/webdavcontent.cxx b/ucb/source/ucp/webdav/webdavcontent.cxx
index 2bfac03..7ea094b 100644
--- a/ucb/source/ucp/webdav/webdavcontent.cxx
+++ b/ucb/source/ucp/webdav/webdavcontent.cxx
@@ -835,16 +835,16 @@ void SAL_CALL Content::removeProperty( const rtl::OUString& Name )
     uno::Reference< ucb::XCommandEnvironment > xEnv;
 
 #if 0
     // @@@ REMOVEABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
     try
     {
         beans::Property aProp
             = getPropertySetInfo( xEnv, sal_False /* don't cache data */ )
                 ->getPropertyByName( Name );
 
-        if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVEABLE ) )
+        if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVABLE ) )
         {
-            // Not removeable!
+            // Not removable!
             throw beans::NotRemoveableException();
         }
     }
@@ -835,16 +835,16 @@ void SAL_CALL Content::removeProperty( const rtl::OUString& Name )
 
 #if 0
-    // @@@ REMOVEABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
+    // @@@ REMOVABLE z.Z. nicht richtig an der PropSetInfo gesetzt!!!
     try
     {
diff --git a/ucbhelper/source/provider/contenthelper.cxx b/ucbhelper/source/provider/contenthelper.cxx
index d292218..c9ce548 100644
--- a/ucbhelper/source/provider/contenthelper.cxx
+++ b/ucbhelper/source/provider/contenthelper.cxx
@@ -577,8 +577,8 @@ void SAL_CALL ContentImplHelper::addProperty(
 
         if ( xContainer.is() )
         {
-            // Property is always removeable.
-            Attributes |= beans::PropertyAttribute::REMOVEABLE;
+            // Property is always removable.
+            Attributes |= beans::PropertyAttribute::REMOVABLE;
 
             try
             {
@@ -642,9 +642,9 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
         beans::Property aProp
             = getPropertySetInfo( xEnv )->getPropertyByName( Name );
 
-        if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVEABLE ) )
+        if ( !( aProp.Attributes & beans::PropertyAttribute::REMOVABLE ) )
         {
-            // Not removeable!
+            // Not removable!
             throw beans::NotRemoveableException();
         }
     }
@@ -684,7 +684,7 @@ void SAL_CALL ContentImplHelper::removeProperty( const rtl::OUString& Name )
             catch ( beans::NotRemoveableException const & )
             {
                 OSL_FAIL(
-                    "ContentImplHelper::removeProperty - Unremoveable!" );
+                    "ContentImplHelper::removeProperty - Unremovable!" );
                 throw;
             }
 